==> touhoulittlemaid-fabric-1.20.1-0.1.4-forge1.3.8-sources.jar: com/github/tartaricacid/touhoulittlemaid/init/InitCapabilities.java <==
package com.github.tartaricacid.touhoulittlemaid.init;

import cn.sh1rocu.touhoulittlemaid.util.itemhandler.entity.EntityArmorInvWrapper;
import com.github.tartaricacid.touhoulittlemaid.entity.passive.EntityMaid;
import com.github.tartaricacid.touhoulittlemaid.inventory.handler.BaubleItemHandler;
import com.github.tartaricacid.touhoulittlemaid.inventory.handler.MaidBackpackHandler;
import com.github.tartaricacid.touhoulittlemaid.inventory.handler.MaidHandsInvWrapper;
import dev.onyxstudios.cca.api.v3.component.ComponentKey;
import dev.onyxstudios.cca.api.v3.component.ComponentRegistry;
import dev.onyxstudios.cca.api.v3.entity.EntityComponentFactoryRegistry;
import dev.onyxstudios.cca.api.v3.entity.EntityComponentInitializer;

import static cn.sh1rocu.touhoulittlemaid.TouhouLittleMaidFabric.getResourceLocation;

public class InitCapabilities implements EntityComponentInitializer {
    public static final ComponentKey<MaidHandsInvWrapper> MAID_HAND = ComponentRegistry.getOrCreate(getResourceLocation("maid_hand"), MaidHandsInvWrapper.class);
    public static final ComponentKey<EntityArmorInvWrapper> MAID_ARMOR = ComponentRegistry.getOrCreate(getResourceLocation("maid_armor"), EntityArmorInvWrapper.class);
    public static final ComponentKey<MaidBackpackHandler> MAID_INV = ComponentRegistry.getOrCreate(getResourceLocation("maid_inv"), MaidBackpackHandler.class);
    public static final ComponentKey<BaubleItemHandler> MAID_BAUBLE = ComponentRegistry.getOrCreate(getResourceLocation("maid_bauble"), BaubleItemHandler.class);

    @Override
    public void registerEntityComponentFactories(EntityComponentFactoryRegistry registry) {
        registry.registerFor(EntityMaid.class, MAID_HAND, MaidHandsInvWrapper::new);
        registry.registerFor(EntityMaid.class, MAID_ARMOR, EntityArmorInvWrapper::new);
        registry.registerFor(EntityMaid.class, MAID_INV, maid -> new MaidBackpackHandler(36, maid));
        registry.registerFor(EntityMaid.class, MAID_BAUBLE, maid -> new BaubleItemHandler(9));
    }
}

==> touhoulittlemaid-fabric-1.20.1-0.2.0-forge1.4.2-sources.jar: com/github/tartaricacid/touhoulittlemaid/init/InitCapabilities.java <==
package com.github.tartaricacid.touhoulittlemaid.init;

import cn.sh1rocu.touhoulittlemaid.util.itemhandler.entity.EntityArmorInvWrapper;
import com.github.tartaricacid.touhoulittlemaid.entity.passive.EntityMaid;
import com.github.tartaricacid.touhoulittlemaid.inventory.handler.BaubleItemHandler;
import com.github.tartaricacid.touhoulittlemaid.inventory.handler.MaidBackpackHandler;
import com.github.tartaricacid.touhoulittlemaid.inventory.handler.MaidHandsInvWrapper;
import dev.onyxstudios.cca.api.v3.component.ComponentKey;
import dev.onyxstudios.cca.api.v3.component.ComponentRegistry;
import dev.onyxstudios.cca.api.v3.entity.EntityComponentFactoryRegistry;
import dev.onyxstudios.cca.api.v3.entity.EntityComponentInitializer;

import static cn.sh1rocu.touhoulittlemaid.TouhouLittleMaidFabric.getResourceLocation;

public class InitCapabilities implements EntityComponentInitializer {
    public static final ComponentKey<MaidHandsInvWrapper> MAID_HAND = ComponentRegistry.getOrCreate(getResourceLocation("maid_hand"), MaidHandsInvWrapper.class);
    public static final ComponentKey<EntityArmorInvWrapper> MAID_ARMOR = ComponentRegistry.getOrCreate(getResourceLocation("maid_armor"), EntityArmorInvWrapper.class);
    public static final ComponentKey<MaidBackpackHandler> MAID_INV = ComponentRegistry.getOrCreate(getResourceLocation("maid_inv"), MaidBackpackHandler.class);
    public static final ComponentKey<BaubleItemHandler> MAID_BAUBLE = ComponentRegistry.getOrCreate(getResourceLocation("maid_bauble"), BaubleItemHandler.class);

    @Override
    public void registerEntityComponentFactories(EntityComponentFactoryRegistry registry) {
        registry.registerFor(EntityMaid.class, MAID_HAND, MaidHandsInvWrapper::new);
        registry.registerFor(EntityMaid.class, MAID_ARMOR, EntityArmorInvWrapper::new);
        registry.registerFor(EntityMaid.class, MAID_INV, maid -> new MaidBackpackHandler(36, maid));
        registry.registerFor(EntityMaid.class, MAID_BAUBLE, maid -> new BaubleItemHandler(EntityMaid.BAUBLE_INV_SIZE));
    }
}
